@@ -23,11 +23,11 @@ from typing import (
     Union,
 )
 
-from kiara.context.config import KiaraConfig, KiaraContextConfig
+from kiara.context.config import KiaraConfig, KiaraContextConfig, KiaraRuntimeConfig
 from kiara.data_types import DataType
 from kiara.defaults import KIARA_DB_MIGRATIONS_CONFIG, KIARA_DB_MIGRATIONS_FOLDER
 from kiara.interfaces import get_console
-from kiara.interfaces.python_api import StoreValueResult, StoreValuesResult
+from kiara.interfaces.python_api.value import StoreValueResult, StoreValuesResult
 from kiara.models import KiaraModel
 from kiara.models.context import ContextSummary
 from kiara.models.info import InfoModelGroup, ItemInfo, KiaraModelClassesInfo
@@ -50,6 +50,7 @@ from kiara.registries.models import ModelRegistry
 from kiara.registries.modules import ModuleRegistry
 from kiara.registries.operations import OperationRegistry
 from kiara.registries.types import TypeRegistry
+from kiara.registries.workflows import WorkflowRegistry
 from kiara.utils import is_debug, log_message
 from kiara.utils.class_loading import find_all_archive_types
 from kiara.utils.operations import filter_operations
@@ -100,7 +101,11 @@ class Kiara(object):
     _instance_kiara_config = KiaraConfig()
 
     @classmethod
-    def instance(cls, context_name: Optional[str] = None) -> "Kiara":
+    def instance(
+        cls,
+        context_name: Optional[str] = None,
+        runtime_config: Union[None, Mapping[str, Any], KiaraRuntimeConfig] = None,
+    ) -> "Kiara":
         """The default *kiara* context. In most cases, it's recommended you create and manage your own, though."""
 
         # TODO: make this thread-safe
@@ -113,38 +118,40 @@ class Kiara(object):
             _context_name = cls._instance_kiara_config.default_context
 
         if _context_name in cls._instances.keys():
-            return cls._instances[_context_name]
+            instance = cls._instances[_context_name]
+        else:
+            instance = cls._instance_kiara_config.create_context(context=context_name)
+            cls._instances[_context_name] = instance
 
-        kiara = cls._instance_kiara_config.create_context(context=context_name)
-        cls._instances[_context_name] = kiara
-        return kiara
+        if runtime_config:
+            if isinstance(runtime_config, KiaraRuntimeConfig):
+                runtime_config = runtime_config.dict()
+            instance.update_runtime_config(**runtime_config)
 
-    def __init__(self, config: Optional[KiaraContextConfig] = None):
+        return instance
 
+    def __init__(
+        self,
+        config: Optional[KiaraContextConfig] = None,
+        runtime_config: Optional[KiaraRuntimeConfig] = None,
+    ):
+
+        kc: Optional[KiaraConfig] = None
         if not config:
             kc = KiaraConfig()
             config = kc.get_context_config()
 
+        if not runtime_config:
+            if kc is None:
+                kc = KiaraConfig()
+            runtime_config = kc.runtime_config
+
         self._id: uuid.UUID = ID_REGISTRY.generate(
             id=uuid.UUID(config.context_id), obj=self
         )
         ID_REGISTRY.update_metadata(self._id, kiara_id=self._id)
         self._config: KiaraContextConfig = config
-
-        # if is_debug():
-        #     echo = True
-        # else:
-        #     echo = False
-        # self._engine: Engine = create_engine(
-        #     self._config.db_url,
-        #     echo=echo,
-        #     future=True,
-        #     json_serializer=orm_json_serialize,
-        #     json_deserializer=orm_json_deserialize,
-        # )
-
-        # self._run_alembic_migrations()
-        # self._envs: Optional[Mapping[str, EnvironmentOrm]] = None
+        self._runtime_config: KiaraRuntimeConfig = runtime_config
 
         self._event_registry: EventRegistry = EventRegistry(kiara=self)
         self._type_registry: TypeRegistry = TypeRegistry(self)
@@ -158,6 +165,8 @@ class Kiara(object):
         self._alias_registry: AliasRegistry = AliasRegistry(kiara=self)
         self._destiny_registry: DestinyRegistry = DestinyRegistry(kiara=self)
 
+        self._workflow_registry: WorkflowRegistry = WorkflowRegistry(kiara=self)
+
         self._env_mgmt: Optional[EnvironmentRegistry] = None
 
         metadata_augmenter = CreateMetadataDestinies(kiara=self)
@@ -181,7 +190,6 @@ class Kiara(object):
             config_cls = archive_cls._config_cls
             archive_config = config_cls(**archive.config)
             archive_obj = archive_cls(archive_id=archive.archive_uuid, config=archive_config)  # type: ignore
-
             for supported_type in archive_obj.supported_item_types():
                 if supported_type == "data":
                     self.data_registry.register_data_archive(
@@ -196,6 +204,9 @@ class Kiara(object):
                 if supported_type == "destiny":
                     self.destiny_registry.register_destiny_archive(archive_obj, alias=archive_alias)  # type: ignore
 
+                if supported_type == "workflow":
+                    self.workflow_registry.register_archive(archive_obj, alias=archive_alias)  # type: ignore
+
     def _run_alembic_migrations(self):
         script_location = os.path.abspath(KIARA_DB_MIGRATIONS_FOLDER)
         dsn = self._config.db_url
@@ -215,6 +226,17 @@ class Kiara(object):
     def context_config(self) -> KiaraContextConfig:
         return self._config
 
+    @property
+    def runtime_config(self) -> KiaraRuntimeConfig:
+        return self._runtime_config
+
+    def update_runtime_config(self, **settings) -> KiaraRuntimeConfig:
+
+        for k, v in settings.items():
+            setattr(self.runtime_config, k, v)
+
+        return self.runtime_config
+
     @property
     def context_info(self) -> "KiaraContextInfo":
 
@@ -266,6 +288,10 @@ class Kiara(object):
     def data_registry(self) -> DataRegistry:
         return self._data_registry
 
+    @property
+    def workflow_registry(self) -> WorkflowRegistry:
+        return self._workflow_registry
+
     @property
     def event_registry(self) -> EventRegistry:
         return self._event_registry
@@ -531,46 +557,46 @@ class KiaraContextInfo(KiaraModel):
         return result
 
 
-def delete_context(kiara_config: KiaraConfig, context_name: str):
-
-    kiara_context_config = kiara_config.get_context_config(context_name=context_name)
-    kiara = Kiara(config=kiara_context_config)
-
-    data_archives = kiara.data_registry.data_archives.values()
-    alias_archives = kiara.alias_registry.alias_archives.values()
-    job_archives = kiara.job_registry.job_archives.values()
-    destiny_archives = kiara.destiny_registry.destiny_archives.values()
-
-    clashes: Dict[str, List[KiaraArchive]] = {}
-    for context_name, context_config in kiara_config.context_configs.items():
-        k = Kiara(config=context_config)
-        for da in k.data_registry.data_archives.values():
-            if da in data_archives:
-                clashes.setdefault("data", []).append(da)
-        for aa in k.alias_registry.alias_archives.values():
-            if aa in alias_archives:
-                clashes.setdefault("alias", []).append(aa)
-        for ja in k.job_registry.job_archives.values():
-            if ja in job_archives:
-                clashes.setdefault("job", []).append(ja)
-        for dea in k.destiny_registry.destiny_archives.values():
-            if dea in destiny_archives:
-                clashes.setdefault("destiny", []).append(dea)
-
-    if clashes:
-        # TODO: only delete non-clash archives and don't throw exception
-        raise Exception(
-            f"Can't delete context '{context_name}', some archives are used in other contexts: {clashes}"
-        )
-
-    for da in data_archives:
-        da.delete_archive(archive_id=da.archive_id)
-
-    for aa in alias_archives:
-        aa.delete_archive(archive_id=aa.archive_id)
-
-    for ja in job_archives:
-        ja.delete_archive(archive_id=ja.archive_id)
-
-    for dea in destiny_archives:
-        dea.delete_archive(archive_id=dea.archive_id)
+# def delete_context(kiara_config: KiaraConfig, context_name: str):
+#
+#     kiara_context_config = kiara_config.get_context_config(context_name=context_name)
+#     kiara = Kiara(config=kiara_context_config)
+#
+#     data_archives = kiara.data_registry.data_archives.values()
+#     alias_archives = kiara.alias_registry.alias_archives.values()
+#     job_archives = kiara.job_registry.job_archives.values()
+#     destiny_archives = kiara.destiny_registry.destiny_archives.values()
+#
+#     clashes: Dict[str, List[KiaraArchive]] = {}
+#     for context_name, context_config in kiara_config.context_configs.items():
+#         k = Kiara(config=context_config)
+#         for da in k.data_registry.data_archives.values():
+#             if da in data_archives:
+#                 clashes.setdefault("data", []).append(da)
+#         for aa in k.alias_registry.alias_archives.values():
+#             if aa in alias_archives:
+#                 clashes.setdefault("alias", []).append(aa)
+#         for ja in k.job_registry.job_archives.values():
+#             if ja in job_archives:
+#                 clashes.setdefault("job", []).append(ja)
+#         for dea in k.destiny_registry.destiny_archives.values():
+#             if dea in destiny_archives:
+#                 clashes.setdefault("destiny", []).append(dea)
+#
+#     if clashes:
+#         # TODO: only delete non-clash archives and don't throw exception
+#         raise Exception(
+#             f"Can't delete context '{context_name}', some archives are used in other contexts: {clashes}"
+#         )
+#
+#     for da in data_archives:
+#         da.delete_archive(archive_id=da.archive_id)
+#
+#     for aa in alias_archives:
+#         aa.delete_archive(archive_id=aa.archive_id)
+#
+#     for ja in job_archives:
+#         ja.delete_archive(archive_id=ja.archive_id)
+#
+#     for dea in destiny_archives:
+#         dea.delete_archive(archive_id=dea.archive_id)
