@@ -83,6 +83,9 @@ DEFAULT_JOB_STORE_MARKER = "default_job_store"
 DEFAULT_ALIAS_STORE_MARKER = "default_alias_store"
 """Name for the default context alias store."""
 
+DEFAULT_WORKFLOW_STORE_MARKER = "default_workflow_store"
+"""Name for the default context workflow store."""
+
 METADATA_DESTINY_STORE_MARKER = "metadata"
 """Name for the default context destiny store."""
 
@@ -154,6 +157,7 @@ ORPHAN_PEDIGREE_OUTPUT_NAME = "__orphan__"
 NO_MODULE_TYPE = "EXTERNAL_DATA"
 
 INVALID_HASH_MARKER = ""
+
 INVALID_SIZE_MARKER = -1
 NO_SERIALIZATION_MARKER = "-- serialization not supported --"
 KIARA_ROOT_TYPE_NAME = "__kiara__"
@@ -168,6 +172,8 @@ KIARA_HASH_FUNCTION = mmh3.hash
 
 ANY_TYPE_NAME = "any"
 
+DEFAULT_ENV_HASH_KEY = "default"
+
 LOAD_CONFIG_PLACEHOLDER = "__placeholder__"
 
 DATA_TYPE_CATEGORY_ID = "metadata.type"
