@@ -10,7 +10,7 @@ import rich_click as click
 import shutil
 import structlog
 import sys
-from typing import Optional
+from typing import Optional, Tuple
 
 from kiara import Kiara
 from kiara.interfaces.tui.pager import PagerApp
@@ -152,13 +152,6 @@ def list_values(
 
 @data.command(name="explain")
 @click.argument("value_id", nargs=-1, required=True)
-@click.option(
-    "--metadata/--no-metadata",
-    "-m",
-    help="Display value metadata.",
-    is_flag=True,
-    default=True,
-)
 @click.option(
     "--pedigree", "-P", help="Display pedigree information for the value.", is_flag=True
 )
@@ -190,12 +183,14 @@ def list_values(
     help="Resolve and display values this value is a destiny for.",
     is_flag=True,
 )
+@click.option(
+    "--environment", "-e", help="Show environment hashes and data.", is_flag=True
+)
 @output_format_option()
 @click.pass_context
 def explain_value(
     ctx,
-    value_id: str,
-    metadata: bool,
+    value_id: Tuple[str],
     pedigree: bool,
     serialized: bool,
     format: str,
@@ -204,6 +199,7 @@ def explain_value(
     destinies: bool,
     destiny_backlinks: bool,
     lineage: bool,
+    environment: bool,
 ):
     """Print the metadata of a stored value.
 
@@ -213,7 +209,6 @@ def explain_value(
     kiara_obj: Kiara = ctx.obj["kiara"]
 
     render_config = {
-        "show_metadata": metadata,
         "show_pedigree": pedigree,
         "show_serialized": serialized,
         "show_data_preview": preview_data,
@@ -221,6 +216,8 @@ def explain_value(
         "show_destinies": destinies,
         "show_destiny_backlinks": destiny_backlinks,
         "show_lineage": lineage,
+        "show_environment_hashes": environment,
+        "show_environment_data": False,
     }
 
     all_values = []
@@ -232,7 +229,7 @@ def explain_value(
         all_values.append(value)
 
     if len(all_values) == 1:
-        title = f"Value details for: [b i]{v_id}[/b i]"
+        title = f"Value details for: [b i]{value_id[0]}[/b i]"
     else:
         title = "Value details"
 
