@@ -11,8 +11,10 @@ from kiara.exceptions import (
     InvalidValuesException,
     NoSuchExecutionTargetException,
 )
-from kiara.interfaces.python_api import StoreValuesResult
 from kiara.interfaces.python_api.utils import create_save_config
+
+# from kiara.interfaces.python_api import KiaraContext
+from kiara.interfaces.python_api.value import StoreValuesResult
 from kiara.models.module.jobs import ExecutionContext, JobConfig, JobStatus
 from kiara.models.module.manifest import Manifest
 from kiara.models.module.operation import Operation
@@ -78,7 +80,7 @@ class KiaraOperation(object):
             data = {}
         data.update(self._inputs_raw)
 
-        self._inputs = self._kiara.data_registry.create_valueset(
+        self._inputs = self._kiara.data_registry.create_valuemap(
             data, self.operation.inputs_schema
         )
         return self._inputs
@@ -317,8 +319,8 @@ class KiaraOperation(object):
         alias_map = create_save_config(field_names=result.field_names, aliases=aliases)
 
         store_result = self._kiara.save_values(values=result, alias_map=alias_map)
-        if self.operation.module.characteristics.is_idempotent:
-            self._kiara.job_registry.store_job_record(job_id=job_id)
+        # if self.operation.module.characteristics.is_idempotent:
+        self._kiara.job_registry.store_job_record(job_id=job_id)
 
         return store_result
 
@@ -328,6 +330,7 @@ class KiaraOperation(object):
         show_operation_doc = config.get("show_operation_doc", True)
         show_inputs = config.get("show_inputs", False)
         show_outputs_schema = config.get("show_outputs_schema", False)
+        show_headers = config.get("show_headers", True)
 
         items: List[Any] = []
 
@@ -338,7 +341,8 @@ class KiaraOperation(object):
             items.append(Markdown(self.operation.doc.full_doc, style="i"))
 
         if show_inputs:
-            items.append("\nInputs:")
+            if show_headers:
+                items.append("\nInputs:")
             try:
                 op_inputs = self.operation_inputs
                 inputs: Any = create_value_map_status_renderable(op_inputs)
@@ -348,7 +352,8 @@ class KiaraOperation(object):
                 inputs = f"[red bold]{e}[/red bold]"
             items.append(inputs)
         if show_outputs_schema:
-            items.append("\nOutputs:")
+            if show_headers:
+                items.append("\nOutputs:")
             outputs_schema = create_table_from_field_schemas(
                 _add_default=False,
                 _add_required=False,
