@@ -356,7 +356,8 @@ class SerializedInlineJson(SerializedPreStoreChunks):
         assert self.inline_data is not None
         if self._json_cache is None:
             self._json_cache = orjson.dumps(
-                self.inline_data, option=orjson.OPT_NON_STR_KEYS
+                self.inline_data,
+                option=orjson.OPT_NON_STR_KEYS,
             )
         return self._json_cache
 
@@ -803,6 +804,13 @@ class Value(ValueDetails):
     _is_stored: bool = PrivateAttr(default=False)
     _cached_properties: Optional["ValueMap"] = PrivateAttr(default=None)
 
+    environment_hashes: Mapping[str, Mapping[str, str]] = Field(
+        description="Hashes for the environments this value was created in."
+    )
+    enviroments: Optional[Mapping[str, Mapping[str, Any]]] = Field(
+        description="Information about the environments this value was created in.",
+        default=None,
+    )
     property_links: Mapping[str, uuid.UUID] = Field(
         description="Links to values that are properties of this value.",
         default_factory=dict,
@@ -999,6 +1007,8 @@ class Value(ValueDetails):
         show_destiny_backlinks = render_config.get("show_destiny_backlinks", False)
         show_data = render_config.get("show_data_preview", False)
         show_serialized = render_config.get("show_serialized", False)
+        show_env_data_hashes = render_config.get("show_environment_hashes", False)
+        show_env_data = render_config.get("show_environment_data", False)
 
         table = Table(show_header=False, box=box.SIMPLE)
         table.add_column("Key", style="i")
@@ -1016,7 +1026,14 @@ class Value(ValueDetails):
         table.add_row("", Rule())
         for k in sorted(self.__fields__.keys()):
 
-            if k in ["serialized", "value_id", "aliases", "kiara_id"]:
+            if k in [
+                "serialized",
+                "value_id",
+                "aliases",
+                "kiara_id",
+                "environments",
+                "environment_hashes",
+            ]:
                 continue
 
             attr = getattr(self, k)
@@ -1039,6 +1056,8 @@ class Value(ValueDetails):
             or show_properties
             or show_destinies
             or show_destiny_backlinks
+            or show_env_data_hashes
+            or show_env_data
         ):
             table.add_row("", "")
             table.add_row("", Rule())
@@ -1072,6 +1091,17 @@ class Value(ValueDetails):
             )
             table.add_row("serialized", serialized.create_renderable())
 
+        if show_env_data_hashes:
+            env_hashes = Syntax(
+                orjson_dumps(self.environment_hashes, option=orjson.OPT_INDENT_2),
+                "json",
+                background_color="default",
+            )
+            table.add_row("environment_hashes", env_hashes)
+
+        if show_env_data:
+            raise NotImplementedError()
+
         if show_properties:
             if not self.property_links:
                 table.add_row("properties", "{}")
@@ -1319,7 +1349,10 @@ class ValueMapReadOnly(ValueMap):  # type: ignore
     def create_from_ids(cls, data_registry: "DataRegistry", **value_ids: uuid.UUID):
 
         values = {k: data_registry.get_value(v) for k, v in value_ids.items()}
-        return ValueMapReadOnly.construct(value_items=values)
+        values_schema = {k: v.value_schema for k, v in values.items()}
+        return ValueMapReadOnly.construct(
+            value_items=values, values_schema=values_schema
+        )
 
     value_items: Dict[str, Value] = Field(
         description="The values contained in this set."
@@ -1340,10 +1373,17 @@ class ValueMapWritable(ValueMap):  # type: ignore
 
     @classmethod
     def create_from_schema(
-        cls, kiara: "Kiara", schema: Mapping[str, ValueSchema], pedigree: ValuePedigree
+        cls,
+        kiara: "Kiara",
+        schema: Mapping[str, ValueSchema],
+        pedigree: ValuePedigree,
+        unique_value_ids: bool = False,
     ) -> "ValueMapWritable":
 
-        v = ValueMapWritable(values_schema=schema, pedigree=pedigree)
+        v = ValueMapWritable(
+            values_schema=schema, pedigree=pedigree, unique_value_ids=unique_value_ids
+        )
+        v._kiara = kiara
         v._data_registry = kiara.data_registry
         return v
 
@@ -1353,8 +1393,13 @@ class ValueMapWritable(ValueMap):  # type: ignore
     pedigree: ValuePedigree = Field(
         description="The pedigree to add to all of the result values."
     )
+    unique_value_ids: bool = Field(
+        description="Whether this value map always creates new value(id)s, even when a dataset with matching hash is found.",
+        default=False,
+    )
 
     _values_uncommitted: Dict[str, Any] = PrivateAttr(default_factory=dict)
+    _kiara: "Kiara" = PrivateAttr(default=None)
     _data_registry: "DataRegistry" = PrivateAttr(default=None)
     _auto_commit: bool = PrivateAttr(default=True)
 
@@ -1389,7 +1434,7 @@ class ValueMapWritable(ValueMap):  # type: ignore
                 schema=schema,
                 pedigree=self.pedigree,
                 pedigree_output_name=field_name,
-                reuse_existing=False,
+                reuse_existing=not self.unique_value_ids,
             )
 
         self._values_uncommitted.pop(field_name)
