@@ -64,6 +64,7 @@ from kiara.registries.data.data_store import DataArchive, DataStore
 from kiara.registries.ids import ID_REGISTRY
 from kiara.utils import log_exception, log_message
 from kiara.utils.data import pretty_print_data
+from kiara.utils.hashing import NONE_CID
 
 if TYPE_CHECKING:
     from kiara.context import Kiara
@@ -112,6 +113,7 @@ class DataRegistry(object):
                 is_constant=True,
                 doc="Special value, indicating a field is not set.",  # type: ignore
             ),
+            environment_hashes={},
             value_status=ValueStatus.NOT_SET,
             value_size=0,
             value_hash=INVALID_HASH_MARKER,
@@ -128,14 +130,15 @@ class DataRegistry(object):
             value_id=NONE_VALUE_ID,
             kiara_id=self._kiara.id,
             value_schema=ValueSchema(
-                type="special_type",
+                type="none",
                 default=SpecialValue.NO_VALUE,
                 is_constant=True,
                 doc="Special value, indicating a field is set with a 'none' value.",  # type: ignore
             ),
+            environment_hashes={},
             value_status=ValueStatus.NONE,
             value_size=0,
-            value_hash=-2,
+            value_hash=str(NONE_CID),
             pedigree=ORPHAN,
             pedigree_output_name="__void__",
             data_type_class=special_value_cls,
@@ -606,7 +609,7 @@ class DataRegistry(object):
             )
 
         if schema.default in [None, SpecialValue.NO_VALUE, SpecialValue.NOT_SET]:
-            if data in [None, SpecialValue.NO_VALUE]:
+            if data is None or data is SpecialValue.NO_VALUE:
                 return (self.NONE_VALUE, False)
             elif data is SpecialValue.NOT_SET:
                 return (self.NOT_SET_VALUE, False)
@@ -632,6 +635,7 @@ class DataRegistry(object):
                 value_hash,
                 value_size,
             ) = self._find_existing_value(data=data, schema=schema)
+
             if _existing is not None:
                 # TODO: check pedigree
                 return (_existing, False)
@@ -666,6 +670,7 @@ class DataRegistry(object):
             value_id=v_id,
             data=data,
             schema=schema,
+            environment_hashes=self._kiara.environment_registry.environment_hashes,
             serialized=serialized,
             status=status,
             value_hash=value_hash,
@@ -818,29 +823,6 @@ class DataRegistry(object):
 
         return parsed
 
-        # op_type: DeSerializeOperationType = self._kiara.operation_registry.get_operation_type("deserialize")  # type: ignore
-        # ops = op_type.find_deserialzation_operation_for_type_and_profile(
-        #     serialized_data.data_type, serialized_data.serialization_profile
-        # )
-        #
-        # if len(ops) > 1:
-        #     raise Exception("No unique op.")
-        #
-        # if not ops:
-        #     raise Exception(
-        #         f"No deserialize operation found for data type: {value.data_type_name}"
-        #     )
-        #
-        # op = ops[0]
-        # inputs = {"value": serialized_data}
-        #
-        # result = op.run(kiara=self._kiara, inputs=inputs)
-        #
-        # python_object = result.get_value_data("python_object")
-        # self._cached_data[value.value_id] = python_object
-        #
-        # return python_object
-
     def load_values(self, values: Mapping[str, Optional[uuid.UUID]]) -> ValueMap:
 
         value_items = {}
@@ -860,7 +842,7 @@ class DataRegistry(object):
         result_values = self.load_values(values=values)
         return {k: v.data for k, v in result_values.items()}
 
-    def create_valueset(
+    def create_valuemap(
         self, data: Mapping[str, Any], schema: Mapping[str, ValueSchema]
     ) -> ValueMap:
         """Extract a set of [Value][kiara.data.values.Value] from Python data and ValueSchemas."""
