@@ -32,6 +32,7 @@ class EnvironmentRegistry(object):
         self,
     ):
         self._environments: Optional[Dict[str, RuntimeEnvironment]] = None
+        self._environment_hashes: Optional[Dict[str, Mapping[str, str]]] = None
 
         self._full_env_model: Optional[BaseModel] = None
 
@@ -46,6 +47,19 @@ class EnvironmentRegistry(object):
             )
         return envs[0]
 
+    @property
+    def environment_hashes(self) -> Mapping[str, Mapping[str, str]]:
+
+        if self._environment_hashes is not None:
+            return self._environment_hashes
+
+        result = {}
+        for env_name, env in self.environments.items():
+            result[env_name] = env.env_hashes
+
+        self._environment_hashes = result
+        return self._environment_hashes
+
     @property
     def environments(self) -> Mapping[str, RuntimeEnvironment]:
         """Return all environments in this kiara runtime context."""
@@ -71,7 +85,7 @@ class EnvironmentRegistry(object):
             name = sc.get_environment_type_name()
             envs[name] = sc.create_environment_model()
 
-        self._environments = envs
+        self._environments = {k: envs[k] for k in sorted(envs.keys())}
         return self._environments
 
     @property
