@@ -11,6 +11,7 @@ import uuid
 from bidict import bidict
 from typing import TYPE_CHECKING, Any, Dict, Iterable, Mapping, Optional, Type
 
+from kiara.context.config import JobCacheStrategy
 from kiara.models.events import KiaraEvent
 from kiara.models.events.job_registry import (
     JobArchiveAddedEvent,
@@ -34,12 +35,32 @@ MANIFEST_SUB_PATH = "manifests"
 
 
 class JobArchive(BaseArchive):
+    # @abc.abstractmethod
+    # def find_matching_job_record(
+    #     self, inputs_manifest: InputsManifest
+    # ) -> Optional[JobRecord]:
+    #     pass
+
     @abc.abstractmethod
-    def find_matching_job_record(
-        self, inputs_manifest: InputsManifest
-    ) -> Optional[JobRecord]:
+    def retrieve_all_job_hashes(
+        self, manifest_hash: Optional[str] = None, inputs_hash: Optional[str] = None
+    ) -> Iterable[str]:
+        """Retrieve a list of all job record hashes (cids) that match the given filter arguments.
+
+        A job record hash includes information about the module type used in the job, the module configuration, as well as input field names and value ids for the values used in those inputs.
+
+        If the job archive retrieves its jobs in a dynamic way, this will return 'None'.
+        """
+
+    @abc.abstractmethod
+    def _retrieve_record_for_job_hash(self, job_hash: str) -> Optional[JobRecord]:
         pass
 
+    def retrieve_record_for_job_hash(self, job_hash: str) -> Optional[JobRecord]:
+
+        job_record = self._retrieve_record_for_job_hash(job_hash=job_hash)
+        return job_record
+
 
 class JobStore(JobArchive):
     @abc.abstractmethod
@@ -47,10 +68,108 @@ class JobStore(JobArchive):
         pass
 
 
+class JobMatcher(abc.ABC):
+    def __init__(self, kiara: "Kiara"):
+
+        self._kiara: Kiara = kiara
+
+    @abc.abstractmethod
+    def find_existing_job(self, inputs_manifest: InputsManifest) -> Optional[JobRecord]:
+        pass
+
+
+class NoneJobMatcher(JobMatcher):
+    def find_existing_job(self, inputs_manifest: InputsManifest) -> Optional[JobRecord]:
+        return None
+
+
+class ValueIdJobMatcher(JobMatcher):
+    def find_existing_job(self, inputs_manifest: InputsManifest) -> Optional[JobRecord]:
+
+        matches = []
+
+        for store_id, archive in self._kiara.job_registry.job_archives.items():
+
+            match = archive.retrieve_record_for_job_hash(
+                job_hash=inputs_manifest.job_hash
+            )
+            if match:
+                matches.append(match)
+
+        if len(matches) == 0:
+            return None
+        elif len(matches) > 1:
+            raise Exception(
+                f"Multiple stores have a record for inputs manifest '{inputs_manifest}', this is not supported (yet)."
+            )
+
+        job_record = matches[0]
+        job_record._is_stored = True
+
+        return job_record
+
+
+class DataHashJobMatcher(JobMatcher):
+    def find_existing_job(self, inputs_manifest: InputsManifest) -> Optional[JobRecord]:
+
+        matches = []
+
+        for store_id, archive in self._kiara.job_registry.job_archives.items():
+
+            match = archive.retrieve_record_for_job_hash(
+                job_hash=inputs_manifest.job_hash
+            )
+            if match:
+                matches.append(match)
+
+        if len(matches) > 1:
+            raise Exception(
+                f"Multiple stores have a record for inputs manifest '{inputs_manifest}', this is not supported (yet)."
+            )
+
+        elif len(matches) == 1:
+
+            job_record = matches[0]
+            job_record._is_stored = True
+
+            return job_record
+
+        inputs_data_cid = inputs_manifest.calculate_inputs_data_cid(
+            data_registry=self._kiara.data_registry
+        )
+        if not inputs_data_cid:
+            return None
+
+        inputs_data_hash = str(inputs_data_cid)
+
+        matching_records = []
+        for store_id, archive in self._kiara.job_registry.job_archives.items():
+            _matches = archive.retrieve_all_job_hashes(
+                manifest_hash=inputs_manifest.manifest_hash
+            )
+            for _match in _matches:
+                _job_record = archive.retrieve_record_for_job_hash(_match)
+                assert _job_record is not None
+                if _job_record.inputs_data_hash == inputs_data_hash:
+                    matching_records.append(_job_record)
+
+        if not matching_records:
+            return None
+        elif len(matches) > 1:
+            raise Exception(
+                f"Multiple stores have a record for inputs manifest '{inputs_manifest}', this is not supported (yet)."
+            )
+        else:
+            return matching_records[0]
+
+
 class JobRegistry(object):
     def __init__(self, kiara: "Kiara"):
 
         self._kiara: Kiara = kiara
+
+        self._job_matcher_cache: Dict[JobCacheStrategy, JobMatcher] = {}
+
         self._active_jobs: bidict[str, uuid.UUID] = bidict()
         self._failed_jobs: Dict[str, uuid.UUID] = {}
         self._finished_jobs: Dict[str, uuid.UUID] = {}
@@ -69,6 +188,24 @@ class JobRegistry(object):
         # default_file_store = self._kiara.data_registry.get_archive(DEFAULT_STORE_MARKER)
         # self.register_job_archive(default_file_store, store_alias="default_data_store")  # type: ignore
 
+    @property
+    def job_matcher(self) -> JobMatcher:
+
+        strategy = self._kiara.runtime_config.job_cache
+        job_matcher = self._job_matcher_cache.get(strategy, None)
+        if job_matcher is None:
+            if strategy == JobCacheStrategy.no_cache:
+                job_matcher = NoneJobMatcher(kiara=self._kiara)
+            elif strategy == JobCacheStrategy.value_id:
+                job_matcher = ValueIdJobMatcher(kiara=self._kiara)
+            elif strategy == JobCacheStrategy.data_hash:
+                job_matcher = DataHashJobMatcher(kiara=self._kiara)
+            else:
+                raise Exception(f"Job cache strategy not implemented: {strategy}")
+            self._job_matcher_cache[strategy] = job_matcher
+
+        return job_matcher
+
     def suppoerted_event_types(self) -> Iterable[Type[KiaraEvent]]:
 
         return [JobArchiveAddedEvent, JobRecordPreStoreEvent, JobRecordStoredEvent]
@@ -152,14 +289,23 @@ class JobRegistry(object):
             )
             return
 
+        store: JobStore = self.get_archive()  # type: ignore
+        if not isinstance(store, JobStore):
+            raise Exception("Can't store job record to archive: not writable.")
+
+        # if job_record.job_id in self._finished_jobs.values():
+        #     logger.debug(
+        #         "ignore.store.job_record",
+        #         reason="already stored in store",
+        #         job_id=str(job_id),
+        #     )
+        #     return
+
         logger.debug(
             "store.job_record",
             job_hash=job_record.job_hash,
             module_type=job_record.module_type,
         )
-        store: JobStore = self.get_archive()  # type: ignore
-        if not isinstance(store, JobStore):
-            raise Exception("Can't store job record to archive: not writable.")
 
         pre_store_event = JobRecordPreStoreEvent.construct(
             kiara_id=self._kiara.id, job_record=job_record
@@ -177,6 +323,21 @@ class JobRegistry(object):
 
         return self._processor.get_job_record(job_id)
 
+    def retrieve_all_job_records(self) -> Mapping[str, JobRecord]:
+
+        all_records: Dict[str, JobRecord] = {}
+        for archive in self.job_archives.values():
+            all_record_ids = archive.retrieve_all_job_hashes()
+            if all_record_ids is None:
+                return {}
+            for r in all_record_ids:
+                assert r not in all_records.keys()
+                job_record = archive.retrieve_record_for_job_hash(r)
+                assert job_record is not None
+                all_records[r] = job_record
+
+        return all_records
+
     def find_matching_job_record(
         self, inputs_manifest: InputsManifest
     ) -> Optional[uuid.UUID]:
@@ -189,34 +350,22 @@ class JobRegistry(object):
             'None' if no such job exists, a (uuid) job-id if the job is currently running or has run in the past
         """
 
+        log = logger.bind(module_type=inputs_manifest.module_type)
         if inputs_manifest.job_hash in self._active_jobs.keys():
-            logger.debug("job.use_running")
+            log.debug("job.use_running")
             return self._active_jobs[inputs_manifest.job_hash]
 
         if inputs_manifest.job_hash in self._finished_jobs.keys():
             job_id = self._finished_jobs[inputs_manifest.job_hash]
             return job_id
 
-        matches = []
-
-        for store_id, archive in self._job_archives.items():
-            match = archive.find_matching_job_record(inputs_manifest=inputs_manifest)
-            if match:
-                matches.append(match)
-
-        if len(matches) == 0:
+        job_record = self.job_matcher.find_existing_job(inputs_manifest=inputs_manifest)
+        if job_record is None:
             return None
-        elif len(matches) > 1:
-            raise Exception(
-                f"Multiple stores have a record for inputs manifest '{inputs_manifest}', this is not supported (yet)."
-            )
-
-        job_record = matches[0]
-        job_record._is_stored = True
 
         self._finished_jobs[inputs_manifest.job_hash] = job_record.job_id
         self._archived_records[job_record.job_id] = job_record
-        logger.debug("job.use_cached")
+        log.debug("job.use_cached")
         return job_record.job_id
 
     def prepare_job_config(
