@@ -120,7 +120,7 @@ class OperationRegistry(object):
             else:
                 result[type_name] = md
 
-        return OperationTypeClassesInfo.construct(group_alias=alias, type_infos=result)  # type: ignore
+        return OperationTypeClassesInfo.construct(group_alias=alias, item_infos=result)  # type: ignore
 
     @property
     def operation_type_classes(
