@@ -3,7 +3,6 @@
 #  Copyright (c) 2021, University of Luxembourg / DHARPA project
 #
 #  Mozilla Public License, version 2.0 (see LICENSE or https://www.mozilla.org/en-US/MPL/2.0/)
-
 from click.testing import CliRunner
 
 from kiara.interfaces.cli import cli
@@ -15,7 +14,7 @@ def test_operation_list_subcommand():
 
     result = runner.invoke(cli, "operation list")
 
-    assert "table.query.sql" in result.stdout
+    assert "logic.nand" in result.stdout
 
 
 def test_operation_list_by_group_subcommand():
@@ -24,15 +23,17 @@ def test_operation_list_by_group_subcommand():
 
     result = runner.invoke(cli, "operation list --by-type")
 
-    assert "calculate_hash.sha3_256.for.file" in result.stdout
+    assert "logic.nand" in result.stdout
 
 
 def test_operation_explain_subcommand():
 
-    runner = CliRunner()
+    os_env_vars = {"CONSOLE_WIDTH": "400"}
+    runner = CliRunner(env=os_env_vars)
 
-    result = runner.invoke(cli, "operation explain table.query.sql")
+    result = runner.invoke(cli, "operation explain logic.nand")
 
-    assert "table.query.sql" in result.stdout
+    print(result.stdout)
+    assert "A boolean describing this input state" in result.stdout
     # assert "relation_name" in result.stdout
     # assert "Module metadata" in result.stdout
