@@ -8,26 +8,26 @@
 import pytest
 
 from kiara import Kiara
+from kiara.exceptions import InvalidValuesException
 
 
-def test_simple_module_exec(kiara: Kiara):
+def test_module_processing(kiara: Kiara):
 
-    and_mod = kiara.create_module("logic.and")
+    and_mod = kiara.create_manifest("logic.and")
 
     # boolean_schema = ValueSchema(type="boolean")
-
     inputs = {"a": None, "b": True}
-    with pytest.raises(Exception) as e:
-        and_mod.run(**inputs)
+    with pytest.raises(InvalidValuesException) as e:
+        kiara.process(manifest=and_mod, inputs=inputs)
 
-    assert "input field(s) not valid" in str(e.value)
+    assert "a" in e.value.invalid_inputs.keys()
+    assert "not set" in e.value.invalid_inputs["a"]
 
-    # inp_a = ValueOrm(value_data=True, value_schema=boolean_schema, kiara=kiara)
-    # inp_b = ValueOrm(value_data=True, value_schema=boolean_schema, kiara=kiara)
     inputs = {"a": True, "b": True}
-    outputs = and_mod.run(**inputs)
+    outputs = kiara.process(manifest=and_mod, inputs=inputs)
+
     assert outputs.get_value_data("y") is True
 
     inputs = {"a": False, "b": True}
-    outputs = and_mod.run(**inputs)
+    outputs = kiara.process(manifest=and_mod, inputs=inputs)
     assert outputs.get_value_data("y") is False
